==> haskell-stringbuilder-0.5.1-594-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stringbuilder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stringbuilder
version:              0.5.1
visibility:           public
id:                   stringbuilder-0.5.1-HGIO374v8tXH13iJnbQPCv
key:                  stringbuilder-0.5.1-HGIO374v8tXH13iJnbQPCv
license:              MIT
copyright:            (c) 2011-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A writer monad for multi-line string literals
description:          <https://github.com/sol/stringbuilder#readme>
category:             Testing
abi:                  e581cb627a209c90494735802332599c
exposed:              True
exposed-modules:      Data.String.Builder
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/stringbuilder-0.5.1
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/stringbuilder-0.5.1
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/stringbuilder-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stringbuilder
hs-libraries:         HSstringbuilder-0.5.1-HGIO374v8tXH13iJnbQPCv
depends:              base-4.18.3.0
haddock-interfaces:
    /usr/share/doc/haskell-stringbuilder/html/stringbuilder.haddock

haddock-html:         /usr/share/doc/haskell-stringbuilder/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stringbuilder-0.5.1-594.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stringbuilder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stringbuilder
version:              0.5.1
visibility:           public
id:                   stringbuilder-0.5.1-EpQkEfA8MNWCH7ISZnrhCx
key:                  stringbuilder-0.5.1-EpQkEfA8MNWCH7ISZnrhCx
license:              MIT
copyright:            (c) 2011-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A writer monad for multi-line string literals
description:          <https://github.com/sol/stringbuilder#readme>
category:             Testing
abi:                  ce58c956d13fde63a9683eeb24185b75
exposed:              True
exposed-modules:      Data.String.Builder
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/stringbuilder-0.5.1
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/stringbuilder-0.5.1
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/stringbuilder-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stringbuilder
hs-libraries:         HSstringbuilder-0.5.1-EpQkEfA8MNWCH7ISZnrhCx
depends:              base-4.18.3.0
haddock-interfaces:
    /usr/share/doc/haskell-stringbuilder/html/stringbuilder.haddock

haddock-html:         /usr/share/doc/haskell-stringbuilder/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
